@@ -18,7 +18,6 @@ import os
 import shutil
 
 from DIRAC import gLogger
-from DIRAC.Core.Utilities import Time
 from DIRAC.FrameworkSystem.Client.UserProfileClient import UserProfileClient
 from DIRAC.DataManagementSystem.Utilities.DMSHelpers import DMSHelpers
 from LHCbDIRAC.Interfaces.API.DiracLHCb import DiracLHCb
@@ -27,7 +26,7 @@ from DIRAC.FrameworkSystem.Client.ProxyManagerClient import gProxyManager
 from LHCbDIRAC.BookkeepingSystem.Client.LHCB_BKKDBClient import LHCB_BKKDBClient
 from LHCbDIRAC.BookkeepingSystem.Client.BookkeepingClient import BookkeepingClient
 
-from WebAppDIRAC.Lib.WebHandler import WebHandler, asyncGen, WErr
+from WebAppDIRAC.Lib.WebHandler import WebHandler, WErr
 
 
 class BookkeepingBrowserHandler(WebHandler):
@@ -40,21 +39,20 @@ class BookkeepingBrowserHandler(WebHandler):
     def index(self):
         pass
 
-    @asyncGen
     def web_getNodes(self):
 
         _, querytype, tree, dataQuality = self.__parseRequest()
         node = self.get_argument("node", "")
 
-        bk = LHCB_BKKDBClient(web=True)
+        bk = LHCB_BKKDBClient()
 
-        yield self.threadTask(bk.setFileTypes, [])
+        bk.setFileTypes([])
 
         bk.setAdvancedQueries(querytype)
         bk.setParameter(tree)
         bk.setDataQualities(dataQuality)
 
-        retVal = yield self.threadTask(bk.list, node)
+        retVal = bk.list(node)
 
         nodes = []
         if len(retVal) > 0:
@@ -80,35 +78,32 @@ class BookkeepingBrowserHandler(WebHandler):
                     node["qtip"] = i["name"]
                 nodes += [node]
 
-        result = tornado.escape.json_encode(nodes)
-        self.finish(result)
+        return tornado.escape.json_encode(nodes)
 
-    @asyncGen
     def web_getdataquality(self):
-        bk = LHCB_BKKDBClient(web=True)
-        result = yield self.threadTask(bk.getAvailableDataQuality)
+        bk = LHCB_BKKDBClient()
+        result = bk.getAvailableDataQuality()
         if result["OK"]:
             ret = []
             for i in result["Value"]:
                 checked = True if i == "OK" else False
                 ret += [{"name": i, "value": checked}]
-            self.finish({"success": "true", "result": ret})
+            return {"success": "true", "result": ret}
         else:
-            self.finish({"result": [], "error": result["Message"]})
+            return {"result": [], "error": result["Message"]}
 
-    @asyncGen
     def web_getFiles(self):
 
         path, querytype, tree, dataQuality = self.__parseRequest()
 
-        bk = LHCB_BKKDBClient(web=True)
+        bk = LHCB_BKKDBClient()
 
         bk.setAdvancedQueries(querytype)
         bk.setParameter(tree)
         bk.setDataQualities(dataQuality)
 
-        retVal = yield self.threadTask(
-            bk.getLimitedFiles, {"fullpath": path}, {"total": "0"}, self.pageNumber, self.numberOfJobs + self.pageNumber
+        retVal = bk.getLimitedFiles(
+            {"fullpath": path}, {"total": "0"}, self.pageNumber, self.numberOfJobs + self.pageNumber
         )
 
         if not retVal["OK"]:
@@ -127,7 +122,7 @@ class BookkeepingBrowserHandler(WebHandler):
                 size = self.__bytestr(extras["GlobalStatistics"]["Files Size"])
                 extras["GlobalStatistics"]["Files Size"] = size
 
-            timestamp = Time.dateTime().strftime("%Y-%m-%d %H:%M [UTC]")
+            timestamp = datetime.datetime.utcnow().strftime("%Y-%m-%d %H:%M [UTC]")
             data = {
                 "success": "true",
                 "result": records,
@@ -138,7 +133,7 @@ class BookkeepingBrowserHandler(WebHandler):
         else:
             data = {"success": "false", "result": [], "error": "Nothing to display!"}
 
-        self.finish(data)
+        return data
 
     ################################################################################
     @staticmethod
@@ -186,20 +181,17 @@ class BookkeepingBrowserHandler(WebHandler):
 
         return path, querytype, tree, dataQuality
 
-    @asyncGen
     def web_getStatistics(self):
 
         path, querytype, tree, dataQuality = self.__parseRequest()
 
-        bk = LHCB_BKKDBClient(web=True)
+        bk = LHCB_BKKDBClient()
 
         bk.setAdvancedQueries(querytype)
         bk.setParameter(tree)
         bk.setDataQualities(dataQuality)
 
-        retVal = yield self.threadTask(
-            bk.getLimitedInformations, self.pageNumber, self.numberOfJobs + self.pageNumber, path
-        )
+        retVal = bk.getLimitedInformations(self.pageNumber, self.numberOfJobs + self.pageNumber, path)
         if retVal["OK"]:
             value = {}
             value["nbfiles"] = retVal["Value"]["Number of files"]
@@ -209,7 +201,7 @@ class BookkeepingBrowserHandler(WebHandler):
         else:
             data = {"success": "false", "result": [], "error": retVal["Message"]}
         # data = {"success":"true","result":{'nbfiles':0,'nbevents':0,'fsize':0}}
-        self.finish(data)
+        return data
 
     @staticmethod
     def __niceNumbers(number):
@@ -222,12 +214,11 @@ class BookkeepingBrowserHandler(WebHandler):
         finalList = " ".join(map(str, finalList))
         return finalList
 
-    @asyncGen
     def web_saveDataSet(self):
 
         path, querytype, tree, dataQuality = self.__parseRequest()
 
-        bk = LHCB_BKKDBClient(web=True)
+        bk = LHCB_BKKDBClient()
 
         bk.setAdvancedQueries(querytype)
         bk.setParameter(tree)
@@ -240,14 +231,14 @@ class BookkeepingBrowserHandler(WebHandler):
 
         if fileformat in ("py", "txt"):
             try:
-                data = yield self.threadTask(
-                    bk.writePythonOrJobOptions, self.pageNumber, self.numberOfJobs + self.pageNumber, path, fileformat
+                data = bk.writePythonOrJobOptions(
+                    self.pageNumber, self.numberOfJobs + self.pageNumber, path, fileformat
                 )
             except Exception:
                 data = {"success": "false", "error": str(sys.exc_info()[1])}
         elif "bkQuery" in self.request.arguments:
             bkQuery = dict(json.loads(self.get_argument("bkQuery")))
-            retVal = yield self.threadTask(bk.getFilesWithMetadata, bkQuery)
+            retVal = bk.getFilesWithMetadata(bkQuery)
             if not retVal["OK"]:
                 data = {"success": "false", "error": retVal["Message"]}
             else:
@@ -256,7 +247,7 @@ class BookkeepingBrowserHandler(WebHandler):
                     fileContent += [",".join(str(metadata) for metadata in record)]
                 data = "\n".join(fileContent)
         else:
-            self.finish({"success": "false", "error": "Please provide fileName and format!"})
+            return {"success": "false", "error": "Please provide fileName and format!"}
 
         self.set_header("Content-type", "text/plain")
         self.set_header("Content-Disposition", 'attachment; filename="%s' % fileName)
@@ -267,12 +258,11 @@ class BookkeepingBrowserHandler(WebHandler):
         self.set_header(
             "Expires", (datetime.datetime.utcnow() - datetime.timedelta(minutes=-10)).strftime("%d %b %Y %H:%M:%S GMT")
         )
-        self.finish(data)
+        return data
 
-    @asyncGen
     def web_getBookmarks(self):
         upc = UserProfileClient("Bookkeeping")
-        result = yield self.threadTask(upc.retrieveVar, "Bookmarks")
+        result = upc.retrieveVar("Bookmarks")
         if result["OK"]:
             data = []
             for i in result["Value"]:
@@ -283,33 +273,31 @@ class BookkeepingBrowserHandler(WebHandler):
                 result = {"success": "true", "result": {}}
             else:
                 result = {"success": "false", "error": result["Message"]}
-        self.finish(result)
+        return result
 
-    @asyncGen
     def web_addBookmark(self):
         title = self.get_argument("title", "")
         path = self.get_argument("path", "")
 
         upc = UserProfileClient("Bookkeeping")
-        result = yield self.threadTask(upc.retrieveVar, "Bookmarks")
+        result = upc.retrieveVar("Bookmarks")
         data = result["Value"] if result["OK"] else {}
         if title in data:
             result = {"success": "false", "error": 'The bookmark with the title "' + title + '" is already exists'}
         else:
             data[title] = path
-        result = yield self.threadTask(upc.storeVar, "Bookmarks", data, {"ReadAccess": "ALL"})
+        result = upc.storeVar("Bookmarks", data, {"ReadAccess": "ALL"})
         if result["OK"]:
             result = {"success": "true", "result": "It successfully added to the bookmark!"}
         else:
             result = {"success": "false", "error": result["Message"]}
-        self.finish(result)
+        return result
 
-    @asyncGen
     def web_deleteBookmark(self):
         title = self.get_argument("title", "")
 
         upc = UserProfileClient("Bookkeeping")
-        result = yield self.threadTask(upc.retrieveVar, "Bookmarks")
+        result = upc.retrieveVar("Bookmarks")
 
         data = result["Value"] if result["OK"] else {}
         if title in data:
@@ -317,39 +305,37 @@ class BookkeepingBrowserHandler(WebHandler):
         else:
             result = {"success": "false", "error": "Can't delete not existing bookmark: \"" + title + '"'}
 
-        result = yield self.threadTask(upc.storeVar, "Bookmarks", data, {"ReadAccess": "ALL"})
+        result = upc.storeVar("Bookmarks", data, {"ReadAccess": "ALL"})
         if result["OK"]:
             result = {"success": "true", "result": "It successfully deleted to the bookmark!"}
         else:
             result = {"success": "false", "error": result["Message"]}
-        self.finish(result)
+        return result
 
-    @asyncGen
     def web_jobinfo(self):
         """
         For retrieving the job information for a given lfn
         """
         lfn = self.get_argument("lfn", None)
 
-        bk = LHCB_BKKDBClient(web=True)
-        result = yield self.threadTask(bk.getJobInfo, lfn)
+        bk = LHCB_BKKDBClient()
+        result = bk.getJobInfo(lfn)
 
         if result is None:
             result = {"success": "false", "error": "Can not retrive job information"}
         else:
             jobinfos = [[key, value] for key, value in result.items()]
             result = {"success": "true", "result": jobinfos}
-        self.finish(result)
+        return result
 
-    @asyncGen
     def web_ancestors(self):
         """
         For retrieving the ancestors for a given lfn
         """
         lfn = self.get_argument("lfn", None)
 
-        bk = LHCB_BKKDBClient(web=True)
-        result = yield self.threadTask(bk.getFileHistory, lfn)
+        bk = LHCB_BKKDBClient()
+        result = bk.getFileHistory(lfn)
         if result["OK"]:
             files = []
             nbrecords = result["Value"]["TotalRecords"]
@@ -364,33 +350,17 @@ class BookkeepingBrowserHandler(WebHandler):
         else:
             WErr.fromSERROR(result)
             result = {"success": "false", "error": result["Message"]}
-        self.finish(result)
+        return result
 
-    @asyncGen
-    def web_logfile(self):
-        """
-        Retrieve the log files for a given lfn
-        """
-        lfn = self.get_argument("lfn", None)
-
-        bk = LHCB_BKKDBClient(web=True)
-        result = yield self.threadTask(bk.getLogfile, lfn)
-        if result["OK"]:
-            result = {"success": "true", "result": result["Value"]}
-        else:
-            result = {"success": "false", "error": "No log file found!"}
-        self.finish(result)
-
-    @asyncGen
     def web_processingpass(self):
         """
         Retrieve the processing pass for a given dataset.
         """
         stepname = self.get_argument("stepName", None)
 
-        bk = LHCB_BKKDBClient(web=True)
+        bk = LHCB_BKKDBClient()
 
-        result = yield self.threadTask(bk.getProcessingPassSteps, {"StepName": stepname})
+        result = bk.getProcessingPassSteps({"StepName": stepname})
         if result["OK"]:
             # convert the data to the correct format
             records = result["Value"]["Records"]
@@ -398,9 +368,8 @@ class BookkeepingBrowserHandler(WebHandler):
             result = {"success": "true", "result": steps}
         else:
             result = {"success": "false", "error": result["Message"]}
-        self.finish(result)
+        return result
 
-    @asyncGen
     def web_stepmetadata(self):
         """
         Retrieve the processing pass for a given dataset.
@@ -409,9 +378,9 @@ class BookkeepingBrowserHandler(WebHandler):
         if bkQuery is not None:
             bkQuery = dict(json.loads(bkQuery))
 
-        bk = LHCB_BKKDBClient(web=True)
+        bk = LHCB_BKKDBClient()
 
-        result = yield self.threadTask(bk.getStepsMetadata, bkQuery)
+        result = bk.getStepsMetadata(bkQuery)
 
         if result["OK"]:
             # convert the data to the correct format
@@ -420,9 +389,8 @@ class BookkeepingBrowserHandler(WebHandler):
             result = {"success": "true", "result": steps}
         else:
             result = {"success": "false", "error": result["Message"]}
-        self.finish(result)
+        return result
 
-    @asyncGen
     def web_conditions(self):
         """
         Retrieve the simulation or data taking conditions
@@ -431,7 +399,7 @@ class BookkeepingBrowserHandler(WebHandler):
         if bkQuery is not None:
             bkQuery = dict(json.loads(bkQuery))
 
-        result = yield self.threadTask(BookkeepingClient().getConditions, bkQuery)
+        result = BookkeepingClient().getConditions(bkQuery)
 
         if result["OK"]:
             # convert the data to the correct format
@@ -454,18 +422,17 @@ class BookkeepingBrowserHandler(WebHandler):
             result = {"success": "true", "result": conditions, "CondType": condType}
         else:
             result = {"success": "false", "error": result["Message"]}
-        self.finish(result)
+        return result
 
-    @asyncGen
     def web_runs(self):
         """
         For retrieving list of runs
         """
 
-        bk = LHCB_BKKDBClient(web=True)
+        bk = LHCB_BKKDBClient()
         bk.setParameter("Runlookup")
 
-        retVal = yield self.threadTask(bk.list)
+        retVal = bk.list()
 
         data = []
         if len(retVal) > 0:
@@ -475,18 +442,17 @@ class BookkeepingBrowserHandler(WebHandler):
         else:
             result = {"success": "false", "error": "no data found"}
 
-        self.finish(result)
+        return result
 
-    @asyncGen
     def web_productions(self):
         """
         For retrieving list of runs
         """
 
-        bk = LHCB_BKKDBClient(web=True)
+        bk = LHCB_BKKDBClient()
         bk.setParameter("Productions")
 
-        retVal = yield self.threadTask(bk.list)
+        retVal = bk.list()
 
         data = []
         if len(retVal) > 0:
@@ -496,9 +462,8 @@ class BookkeepingBrowserHandler(WebHandler):
         else:
             result = {"success": "false", "error": "no data found"}
 
-        self.finish(result)
+        return result
 
-    @asyncGen
     def web_t1sites(self):
         """
         Retrive the list of Tier1 sites
@@ -522,15 +487,14 @@ class BookkeepingBrowserHandler(WebHandler):
         for shortSiteName, siteName in shortSiteNames.items():
             data.append({"Name": shortSiteName, "Value": siteName})
 
-        self.finish({"success": "true", "result": sorted(data, key=lambda x: x["Name"])})
+        return {"success": "true", "result": sorted(data, key=lambda x: x["Name"])}
 
-    @asyncGen
     def web_createCatalog(self):
         """It is used for create pool xml catalog"""
 
         _, querytype, tree, dataQuality = self.__parseRequest()
 
-        bk = LHCB_BKKDBClient(web=True)
+        bk = LHCB_BKKDBClient()
         bk.setAdvancedQueries(querytype)
         bk.setParameter(tree)
         bk.setDataQualities(dataQuality)
@@ -547,34 +511,29 @@ class BookkeepingBrowserHandler(WebHandler):
 
         if not result["OK"]:
             gLogger.error("Failed to set shifter proxy", result["Message"])
-            self.finish(
-                {
-                    "success": "false",
-                    "error": "Can not retrieve proxy used to generate the xml catalog! "
-                    "Please upload your proxy to LHCbDIRAC!",
-                }
-            )
-            return
+            return {
+                "success": "false",
+                "error": "Can not retrieve proxy used to generate the xml catalog! "
+                "Please upload your proxy to LHCbDIRAC!",
+            }
 
         proxyFile = result["Value"]
         os.environ["X509_USER_PROXY"] = proxyFile
 
-        retVal = yield self.threadTask(bk.getFilesWithMetadata, bkQuery)
+        retVal = bk.getFilesWithMetadata(bkQuery)
         if not retVal["OK"]:
-            self.finish({"success": "false", "error": retVal["Message"]})
-            return
+            return {"success": "false", "error": retVal["Message"]}
 
         lfns = {}
         for record in retVal["Value"]["Records"][self.pageNumber : self.numberOfJobs + self.pageNumber]:
             fileMetaDict = dict(zip(retVal["Value"]["ParameterNames"], record))
             lfns[fileMetaDict["FileName"]] = fileMetaDict
         if not lfns:
-            self.finish({"success": "false", "error": "No files found"})
-            return
+            return {"success": "false", "error": "No files found"}
 
         tmpdir = tempfile.mkdtemp(prefix=userName)
         catalog = f"{tmpdir}/{fileName}.xml"
-        retVal = yield self.threadTask(DiracLHCb().getInputDataCatalog, list(lfns), siteName, catalog, True)
+        retVal = DiracLHCb().getInputDataCatalog(list(lfns), siteName, catalog, True)
         if not retVal["OK"]:
             raise WErr.fromSERROR(retVal)
 
@@ -591,7 +550,7 @@ class BookkeepingBrowserHandler(WebHandler):
             kwargs = dict(savedType=None, savePfn=slist)
         elif formatType.lower() != "lfn":
             raise NotImplementedError(formatType)
-        yield self.threadTask(bk.writeJobOptions, exists, fileName, **kwargs)
+        bk.writeJobOptions(exists, fileName, **kwargs)
 
         tarFile = "%s.tar.gz" % tmpdir
         with tarfile.open(tarFile, "w:gz") as tar:
@@ -609,4 +568,4 @@ class BookkeepingBrowserHandler(WebHandler):
         self.set_header("Content-Length", len(data))
         self.set_header("Cache-Control", "no-cache, no-store, must-revalidate, max-age=0")
         self.set_header("Pragma", "no-cache")
-        self.finish(data)
+        return data
