@@ -17,20 +17,19 @@ from datetime import datetime
 import tornado
 from DIRAC import gLogger
 from DIRAC.ResourceStatusSystem.Client.PublisherClient import PublisherClient
-from WebAppDIRAC.Lib.WebHandler import WebHandler, WErr, asyncGen
+from WebAppDIRAC.Lib.WebHandler import WebHandler, WErr
 
 
 class DowntimesHandler(WebHandler):
 
     AUTH_PROPS = "authenticated"
 
-    @asyncGen
     def web_getSelectionData(self):
         callback = {"name": set(), "severity": set(), "sites": set()}
 
         gLogger.info("Arguments to web_getSelectionData", repr(self.request.arguments))
 
-        downtimes = yield self.threadTask(PublisherClient().getCachedDowntimes, None, None, None, None)
+        downtimes = PublisherClient().getCachedDowntimes(None, None, None, None)
 
         if downtimes["OK"]:
 
@@ -41,7 +40,7 @@ class DowntimesHandler(WebHandler):
                 callback["name"].add(dt["Name"])
                 callback["severity"].add(dt["Severity"])
 
-        sites = yield self.threadTask(PublisherClient().getSites)
+        sites = PublisherClient().getSites()
         if sites["OK"]:
 
             callback["site"] = sites["Value"]
@@ -54,14 +53,13 @@ class DowntimesHandler(WebHandler):
 
         callback["view"] = [["tabular"], ["availability"]]
 
-        self.finish(callback)
+        return callback
 
-    @asyncGen
     def web_getDowntimesData(self):
         requestParams = self.__requestParams()
         gLogger.info(requestParams)
 
-        retVal = yield self.threadTask(PublisherClient().getSitesResources, list(requestParams["site"]))
+        retVal = PublisherClient().getSitesResources(list(requestParams["site"]))
 
         sitesResources = ""
         if not retVal["OK"]:
@@ -98,7 +96,7 @@ class DowntimesHandler(WebHandler):
             dt["StartDate"] = str(dt["StartDate"])
             dt["EndDate"] = str(dt["EndDate"])
 
-        self.finish({"success": "true", "result": dtList, "total": len(dtList)})
+        return {"success": "true", "result": dtList, "total": len(dtList)}
 
     def __requestParams(self):
         """
@@ -107,12 +105,14 @@ class DowntimesHandler(WebHandler):
         """
         gLogger.always("!!!  PARAMS: ", repr(self.request.arguments))
 
-        responseParams = {"name": [], "severity": [], "site": []}
+        responseParams = {}
 
-        for key in responseParams:
+        for key in ("name", "severity", "site"):
             value = self.get_argument(key, None)
             if value:
                 responseParams[key] = list(json.loads(value))
+            else:
+                responseParams[key] = []
 
         try:
             startDate = f"{self.get_argument('startDate')} {self.get_argument('startTime')}"
