@@ -15,7 +15,7 @@ import six
 from DIRAC import S_OK, S_ERROR, gConfig, gLogger
 from DIRAC.ConfigurationSystem.Client.Helpers.Operations import Operations
 from DIRAC.ConfigurationSystem.Client import PathFinder
-from WebAppDIRAC.Lib.WebHandler import WebHandler, asyncGen, WErr
+from WebAppDIRAC.Lib.WebHandler import WebHandler, WErr
 
 from LHCbDIRAC.BookkeepingSystem.Client.BookkeepingClient import BookkeepingClient
 
@@ -87,20 +87,17 @@ class LHCbStepManagerHandler(WebHandler):
 
         self.write({"success": "true", "total": len(applications), "result": [{"v": x} for x in applications]})
 
-    @asyncGen
     def web_getAppVersions(self):
         app = self.__getArgument("app", "")
         if not app:
-            self.finish({"success": "true", "result": [], "total": 0})
-            return
+            return {"success": "true", "result": [], "total": 0}
 
-        result = yield self.threadTask(getSoftVersions, app)
+        result = getSoftVersions(app)
         if not result["OK"]:
-            self.finish({"success": "false", "result": [], "total": 0, "error": result["Message"]})
-            return
+            return {"success": "false", "result": [], "total": 0, "error": result["Message"]}
 
         versions = result["Value"]
-        self.finish({"success": "true", "total": len(versions), "result": [{"v": x} for x in versions]})
+        return {"success": "true", "total": len(versions), "result": [{"v": x} for x in versions]}
 
     def web_getAppOptionsFormats(self):
         app = self.__getArgument("app", "")
@@ -110,7 +107,7 @@ class LHCbStepManagerHandler(WebHandler):
 
         formats = Operations().getValue("Productions/StepOptionsFormat/%s" % app)
         formats = formats.split(", ") if formats is not None else []
-        self.finish({"success": "true", "total": len(formats), "result": [{"v": x} for x in formats]})
+        return {"success": "true", "total": len(formats), "result": [{"v": x} for x in formats]}
 
     def web_getSelectionData(self):
         callback = {
@@ -185,14 +182,13 @@ class LHCbStepManagerHandler(WebHandler):
             if oneDict[x] is None:
                 oneDict[x] = ""
 
-    @asyncGen
     def web_getSteps(self):
         sfilter = self.__getFilter()
 
-        result = yield self.threadTask(BookkeepingClient().getAvailableSteps, sfilter)
+        result = BookkeepingClient().getAvailableSteps(sfilter)
 
         if not result["OK"]:
-            self.finish({"success": "false", "result": [], "total": 0, "error": result["Message"]})
+            return {"success": "false", "result": [], "total": 0, "error": result["Message"]}
             return
 
         result = result["Value"]
@@ -208,9 +204,8 @@ class LHCbStepManagerHandler(WebHandler):
         for step in steps:
             self.__runtimeProjectsConvert(step)
 
-        self.finish({"success": "true", "result": steps, "total": result["TotalRecords"], "date": None})
+        return {"success": "true", "result": steps, "total": result["TotalRecords"], "date": None}
 
-    @asyncGen
     def web_getStep(self):
         bk = BookkeepingClient()
 
@@ -221,31 +216,31 @@ class LHCbStepManagerHandler(WebHandler):
             pass  # ignore errors
 
         # Get Step Body
-        result = yield self.threadTask(bk.getAvailableSteps, {"StepId": StepId})
+        result = bk.getAvailableSteps({"StepId": StepId})
         if not result["OK"]:
-            self.finish({"success": "false", "result": [], "error": result["Message"]})
+            return {"success": "false", "result": [], "error": result["Message"]}
             return
         result = result["Value"]
         fields = result["ParameterNames"]
         steps = [dict(zip(fields, x)) for x in result["Records"]]
         if len(steps) != 1:
-            self.finish({"success": "false", "result": [], "error": "Requested Step is not found"})
+            return {"success": "false", "result": [], "error": "Requested Step is not found"}
             return
         step = steps[0]
 
         # Get Input Files for the step
-        result = yield self.threadTask(bk.getStepInputFiles, StepId)
+        result = bk.getStepInputFiles(StepId)
         if not result["OK"]:
-            self.finish({"success": "false", "result": [], "error": result["Message"]})
+            return {"success": "false", "result": [], "error": result["Message"]}
             return
         result = result["Value"]
         fields = ["FileType"]  # TODO: replace with result['ParameterNames']
         ift = [dict(zip(fields, x)) for x in result["Records"]]
 
         # Get Output Files for the step
-        result = yield self.threadTask(bk.getStepOutputFiles, StepId)
+        result = bk.getStepOutputFiles(StepId)
         if not result["OK"]:
-            self.finish({"success": "false", "result": [], "error": result["Message"]})
+            return {"success": "false", "result": [], "error": result["Message"]}
             return
         result = result["Value"]
         fields = ["FileType"]  # TODO: replace with result['ParameterNames']
@@ -258,36 +253,34 @@ class LHCbStepManagerHandler(WebHandler):
             step["textInputFileTypes"] = ",".join(["%s" % x["FileType"] for x in ift])
             step["textOutputFileTypes"] = ",".join(["%s" % x["FileType"] for x in oft])
         except Exception as e:
-            self.finish({"success": "false", "result": [], "error": "Can not convert File Types: %s" % str(e)})
+            return {"success": "false", "result": [], "error": "Can not convert File Types: %s" % str(e)}
         self.__runtimeProjectsConvert(step)
         self.__nullConvert(step)
 
-        self.finish({"success": "true", "result": step})
+        return {"success": "true", "result": step}
 
-    @asyncGen
     def web_getRuntimeProjects(self):
 
-        result = yield self.threadTask(BookkeepingClient().getAvailableSteps, {})
+        result = BookkeepingClient().getAvailableSteps({})
         if not result["OK"]:
-            self.finish({"success": "false", "result": [], "error": result["Message"]})
+            return {"success": "false", "result": [], "error": result["Message"]}
             return
 
         fields = result["Value"]["ParameterNames"]
         rows = [dict(zip(fields, x)) for x in result["Value"]["Records"]]
         rows = [{"id": r["StepId"], "text": f"{r['StepName']}({r['StepId']})"} for r in rows if r["Usable"] == "Yes"]
         rows.sort(key=lambda x: x["id"], reverse=True)
-        self.finish({"success": "true", "result": rows, "total": len(rows)})
+        return {"success": "true", "result": rows, "total": len(rows)}
 
-    @asyncGen
     def web_getBKTags(self):
         tag = self.__getArgument("tag", "")
         if not tag:
-            self.finish({"success": "true", "result": [], "total": 0})
+            return {"success": "true", "result": [], "total": 0}
             return
 
-        result = yield self.threadTask(BookkeepingClient().getAvailableTagsFromSteps)
+        result = BookkeepingClient().getAvailableTagsFromSteps()
         if not result["OK"]:
-            self.finish({"success": "false", "result": [], "total": 0, "error": result["Message"]})
+            return {"success": "false", "result": [], "total": 0, "error": result["Message"]}
             return
 
         rows = [{"v": x[1]} for x in result["Value"]["Records"] if x[0] == tag]
@@ -297,30 +290,28 @@ class LHCbStepManagerHandler(WebHandler):
             rows.append({"v": "ONLINE"})
         if "fromPreviousStep" not in [list(tag.values())[0] for tag in rows]:
             rows.append({"v": "fromPreviousStep"})
-        self.finish({"success": "true", "total": len(rows), "result": rows})
+        return {"success": "true", "total": len(rows), "result": rows}
 
-    @asyncGen
     def web_getFileTypes(self):
-        result = yield self.threadTask(BookkeepingClient().getAvailableFileTypes)
+        result = BookkeepingClient().getAvailableFileTypes()
         if not result["OK"]:
-            self.finish({"success": "false", "result": [], "total": 0, "error": result["Message"]})
+            return {"success": "false", "result": [], "total": 0, "error": result["Message"]}
             return
         rows = [dict(zip(["Name", "Description"], x)) for x in result["Value"]["Records"]]
         rows.sort(key=lambda x: x["Name"])
-        self.finish({"success": "true", "total": len(rows), "result": rows})
+        return {"success": "true", "total": len(rows), "result": rows}
 
-    @asyncGen
     def web_addFileType(self):
         name = self.__getArgument("Name", "")
         description = self.__getArgument("Description", "")
         if not name or not description:
-            self.finish({"success": "false", "result": [], "error": "File type specification is incomplete"})
+            return {"success": "false", "result": [], "error": "File type specification is incomplete"}
             return
-        result = yield self.threadTask(BookkeepingClient().insertFileTypes, str(name), str(description), "ROOT")
+        result = BookkeepingClient().insertFileTypes(str(name), str(description), "ROOT")
         if not result["OK"]:
-            self.finish({"success": "false", "result": [], "error": result["Message"]})
+            return {"success": "false", "result": [], "error": result["Message"]}
         else:
-            self.finish({"success": "true", "result": []})
+            return {"success": "true", "result": []}
 
     __stepOrdinaryFields = [
         "StepId",
@@ -354,7 +345,6 @@ class LHCbStepManagerHandler(WebHandler):
             gLogger.error("Cound not covert 's': %s" % str(e))
         return r
 
-    @asyncGen
     def web_saveStep(self):
         params = {}
         for name in self.request.arguments:
@@ -384,15 +374,14 @@ class LHCbStepManagerHandler(WebHandler):
                 if name in params["Step"]:
                     params[name] = params["Step"][name]
                     del params["Step"][name]
-            result = yield self.threadTask(bk.insertStep, params)
+            result = bk.insertStep(params)
         else:
-            result = yield self.threadTask(bk.updateStep, params)
+            result = bk.updateStep(params)
         if not result["OK"]:
-            self.finish({"success": "false", "result": [], "error": result["Message"]})
+            return {"success": "false", "result": [], "error": result["Message"]}
         else:
-            self.finish({"success": "true", "result": []})
+            return {"success": "true", "result": []}
 
-    @asyncGen
     def web_deleteStep(self):
         StepId = 0
         try:
@@ -400,10 +389,10 @@ class LHCbStepManagerHandler(WebHandler):
         except Exception:
             pass
         if not StepId:
-            self.finish({"success": "false", "result": [], "error": "StepId is not correctly specified"})
+            return {"success": "false", "result": [], "error": "StepId is not correctly specified"}
             return
-        result = yield self.threadTask(BookkeepingClient().deleteStep, StepId)
+        result = BookkeepingClient().deleteStep(StepId)
         if not result["OK"]:
-            self.finish({"success": "false", "result": [], "error": result["Message"]})
+            return {"success": "false", "result": [], "error": result["Message"]}
         else:
-            self.finish({"success": "true", "result": []})
+            return {"success": "true", "result": []}
