@@ -9,14 +9,14 @@
 # or submit itself to any jurisdiction.                                       #
 ###############################################################################
 import json
+from datetime import datetime
 
 from DIRAC import gLogger
-from DIRAC.Core.Utilities import Time
 
 from LHCbDIRAC.TransformationSystem.Client.TransformationClient import TransformationClient
 
 from WebAppDIRAC.WebApp.handler.TransformationMonitorHandler import TransformationMonitorHandler
-from WebAppDIRAC.Lib.WebHandler import asyncGen, WErr
+from WebAppDIRAC.Lib.WebHandler import WErr
 from WebAppDIRAC.Lib.SessionData import SessionData
 
 
@@ -50,7 +50,6 @@ class LHCbTransformationMonitorHandler(TransformationMonitorHandler):
         return callback
 
     ################################################################################
-    @asyncGen
     def web_showRunStatus(self):
         callback = {}
         start = int(self.get_argument("start"))
@@ -62,8 +61,8 @@ class LHCbTransformationMonitorHandler(TransformationMonitorHandler):
             raise WErr(400, "Missing %s" % excp)
 
         tsClient = TransformationClient()
-        result = yield self.threadTask(
-            tsClient.getTransformationRunsSummaryWeb, {"TransformationID": id}, [["RunNumber", "DESC"]], start, limit
+        result = tsClient.getTransformationRunsSummaryWeb(
+            {"TransformationID": id}, [["RunNumber", "DESC"]], start, limit
         )
 
         if not result["OK"]:
@@ -90,12 +89,12 @@ class LHCbTransformationMonitorHandler(TransformationMonitorHandler):
                                         "total": total,
                                         "error": "One of the records in service response is corrupted",
                                     }
-                                    self.finish(callback)
+                                    return callback
                                 tmp = {}
                                 for j in range(0, headLength):
                                     tmp[head[j]] = i[j]
                                 callback.append(tmp)
-                            timestamp = Time.dateTime().strftime("%Y-%m-%d %H:%M [UTC]")
+                            timestamp = datetime.utcnow().strftime("%Y-%m-%d %H:%M [UTC]")
                             if extra:
                                 callback = {
                                     "success": "true",
@@ -114,10 +113,9 @@ class LHCbTransformationMonitorHandler(TransformationMonitorHandler):
                     callback = {"success": "false", "result": "", "error": "Data structure is corrupted"}
             else:
                 callback = {"success": "false", "result": "", "error": "There were no data matching your selection"}
-        self.finish(callback)
+        return callback
 
     ################################################################################
-    @asyncGen
     def web_setRunStatus(self):
         callback = {}
         transID = int(self.get_argument("TransformationId"))
@@ -126,22 +124,21 @@ class LHCbTransformationMonitorHandler(TransformationMonitorHandler):
 
         gLogger.info(f"\033[0;31m setTransformationRunStatus({transID}, {runID}, {status}) \033[0m")
         tsClient = TransformationClient()
-        result = result = yield self.threadTask(tsClient.setTransformationRunStatus, transID, runID, status)
+        result = result = tsClient.setTransformationRunStatus(transID, runID, status)
         if result["OK"]:
             callback = {"success": True, "result": True}
         else:
             callback = {"success": "false", "error": result["Message"]}
-        self.finish(callback)
+        return callback
 
-    def _request(self):
-        req = super()._request()
+    def _prepareSearchParameters(self, *args, **kwargs):
+        req = super()._prepareSearchParameters(*args, **kwargs)
         hotFlag = json.loads(self.get_argument("Hot", "[false]"))[-1]
         if hotFlag:
             req["Hot"] = hotFlag
 
         return req
 
-    @asyncGen
     def web_changeHotFlag(self):
         data = self.getSessionData()
         isAuth = False
@@ -155,7 +152,7 @@ class LHCbTransformationMonitorHandler(TransformationMonitorHandler):
 
         tsClient = TransformationClient()
 
-        retVal = yield self.threadTask(tsClient.setHotFlag, prod, hotFlag)
+        retVal = tsClient.setHotFlag(prod, hotFlag)
         if not retVal["OK"]:
             raise WErr.fromSERROR(retVal)
-        self.finish({"success": True, "result": prod})
+        return {"success": True, "result": prod}
