@@ -14,12 +14,11 @@ import json
 import datetime
 import tornado
 
-from WebAppDIRAC.Lib.WebHandler import WebHandler, WErr, asyncGen
+from WebAppDIRAC.Lib.WebHandler import WebHandler, WErr
 
 from DIRAC import S_ERROR, S_OK, gConfig, gLogger
 from DIRAC.ConfigurationSystem.Client import PathFinder
 from DIRAC.Core.Utilities import DictCache
-from DIRAC.Core.Utilities import Time
 
 from LHCbDIRAC.BookkeepingSystem.Client.BookkeepingClient import BookkeepingClient
 from LHCbDIRAC.ProductionManagementSystem.Client.ProductionRequestClient import ProductionRequestClient
@@ -382,13 +381,11 @@ class ProductionRequestManagerHandler(WebHandler):
                     s += " with unknown %s" % ",".join(unknown)
         return s
 
-    @asyncGen
     def web_getSelectionData(self):
         callback = {}
-        retVal = yield self.threadTask(ProductionRequestClient().getFilterOptions)
+        retVal = ProductionRequestClient().getFilterOptions()
         if not retVal["OK"]:
-            self.finish({"success": "false", "result": [], "total": 0, "error": retVal["Message"]})
-            return
+            return {"success": "false", "result": [], "total": 0, "error": retVal["Message"]}
 
         callback["typeF"] = [[i] for i in retVal["Value"]["Type"]]
         callback["stateF"] = [[i] for i in retVal["Value"]["State"]]
@@ -397,15 +394,13 @@ class ProductionRequestManagerHandler(WebHandler):
 
         self.write(callback)
 
-    @asyncGen
     def web_getWG(self):
-        retVal = yield self.threadTask(ProductionRequestClient().getFilterOptions)
+        retVal = ProductionRequestClient().getFilterOptions()
         if not retVal["OK"]:
             raise WErr.fromSERROR(retVal)
         rows = [{"text": i, "name": i} for i in retVal["Value"]["WG"]]
-        self.finish({"OK": True, "result": rows, "total": len(rows)})
+        return {"OK": True, "result": rows, "total": len(rows)}
 
-    @asyncGen
     def web_list(self):
         parent = self.get_argument("anode", 0)
         try:
@@ -416,29 +411,26 @@ class ProductionRequestManagerHandler(WebHandler):
         except Exception as e:
             raise WErr(404, e)
 
-        result = yield self.threadTask(self.getProductionRequestList, parent)
-        self.finish(result)
+        result = self.getProductionRequestList(parent)
+        return result
 
-    @asyncGen
     def web_history(self):
         requestID = self.get_argument("RequestID", "")
         try:
             requestID = int(json.loads(requestID))
         except Exception:
-            self.finish({"success": "false", "result": [], "total": 0, "error": "Request ID is not a number"})
+            return {"success": "false", "result": [], "total": 0, "error": "Request ID is not a number"}
 
-        result = yield self.threadTask(ProductionRequestClient().getRequestHistory, requestID)
+        result = ProductionRequestClient().getRequestHistory(requestID)
         if not result["OK"]:
-            self.finish({"success": "false", "result": [], "total": 0, "error": result["Message"]})
-            return
+            return {"success": "false", "result": [], "total": 0, "error": result["Message"]}
         rows = result["Value"]["Rows"]
         result = []
         for row in rows:
             row["TimeStamp"] = str(row["TimeStamp"])
             result += [[row["TimeStamp"], row["RequestState"], row["RequestUser"]]]
-        self.finish({"success": "true", "result": result, "total": len(result)})
+        return {"success": "true", "result": result, "total": len(result)}
 
-    @asyncGen
     def web_duplicate(self):
         try:
             reqId = self.get_argument("ID")
@@ -446,27 +438,23 @@ class ProductionRequestManagerHandler(WebHandler):
             reqId = int(json.loads(reqId))
             clearpp = json.loads(clearpp)
         except Exception:
-            self.finish({"success": "false", "result": [], "total": 0, "error": "Request ID is not a number"})
+            return {"success": "false", "result": [], "total": 0, "error": "Request ID is not a number"}
 
-        result = yield self.threadTask(ProductionRequestClient().duplicateProductionRequest, reqId, clearpp)
+        result = ProductionRequestClient().duplicateProductionRequest(reqId, clearpp)
         self.write(result)
 
-    @asyncGen
     def web_delete(self):
         try:
             reqId = self.get_argument("ID")
             reqId = int(json.loads(reqId))
         except Exception:
-            self.finish({"success": "false", "result": [], "total": 0, "error": "Request ID is not a number"})
-        result = yield self.threadTask(ProductionRequestClient().deleteProductionRequest, reqId)
+            return {"success": "false", "result": [], "total": 0, "error": "Request ID is not a number"}
+        result = ProductionRequestClient().deleteProductionRequest(reqId)
         self.write(result)
 
-    @asyncGen
     def web_typeandmodels(self):
         types = [(x, x) for x in self.__request_types()]
-        result = yield self.threadTask(
-            ProductionRequestClient().getProductionRequestList, 0, "RequestID", "DESC", 0, 0, {"IsModel": 1}
-        )
+        result = ProductionRequestClient().getProductionRequestList(0, "RequestID", "DESC", 0, 0, {"IsModel": 1})
         models = []
         if not result["OK"]:
             models = []
@@ -476,37 +464,32 @@ class ProductionRequestManagerHandler(WebHandler):
             ]
 
         rows = [{"Name": x[0], "Description": x[1]} for x in types + models]
-        self.finish({"OK": True, "result": rows, "total": len(rows)})
+        return {"OK": True, "result": rows, "total": len(rows)}
 
-    @asyncGen
     def web_bkk_dq_list(self):
-        result = yield self.threadTask(BookkeepingClient().getAvailableDataQuality)
+        result = BookkeepingClient().getAvailableDataQuality()
         if not result["OK"]:
-            self.finish({"success": "false", "result": [], "total": 0, "error": result["Message"]})
-            return
+            return {"success": "false", "result": [], "total": 0, "error": result["Message"]}
         value = []
         if result["Value"]:
             value.append({"v": "ALL"})
         for x in result["Value"]:
             value.append({"v": x})
-        self.finish({"OK": True, "total": len(value), "result": value})
+        return {"OK": True, "total": len(value), "result": value}
 
-    @asyncGen
     def web_bkk_event_types(self):
         addempty = "addempty" in self.request.arguments
-        result = yield self.threadTask(BookkeepingClient().getAvailableEventTypes)
+        result = BookkeepingClient().getAvailableEventTypes()
         if not result["OK"]:
-            self.finish({"success": "false", "result": [], "total": 0, "error": result["Message"]})
-            return
+            return {"success": "false", "result": [], "total": 0, "error": result["Message"]}
         rows = []
         for et in result["Value"]:
             rows.append({"id": et[0], "name": et[1], "text": f"{str(et[0])} - {str(et[1])}"})
         rows.sort(key=lambda x: x["id"])
         if addempty:
             rows.insert(0, {"id": 99999999, "name": "", "text": "&nbsp;"})
-        self.finish({"OK": True, "result": rows, "total": len(rows)})
+        return {"OK": True, "result": rows, "total": len(rows)}
 
-    @asyncGen
     def web_bkk_input_tcks(self):
         pars = {
             "EventTypeId": self.get_argument("eventType", ""),
@@ -516,10 +499,9 @@ class ProductionRequestManagerHandler(WebHandler):
             "ConditionDescription": self.get_argument("simDesc", ""),
         }
         # log.info(str(pars))
-        result = yield self.threadTask(BookkeepingClient().getTCKs, pars)
+        result = BookkeepingClient().getTCKs(pars)
         if not result["OK"]:
-            self.finish({"success": "false", "result": [], "total": 0, "error": result["Message"]})
-            return
+            return {"success": "false", "result": [], "total": 0, "error": result["Message"]}
         gLogger.info(result["Value"])
         value = []
         if result["Value"]:
@@ -527,9 +509,8 @@ class ProductionRequestManagerHandler(WebHandler):
         for x in result["Value"]:
             value.append({"id": str(x), "text": str(x)})
         value.sort(key=lambda x: x["id"])
-        self.finish({"OK": True, "total": len(value), "result": value})
+        return {"OK": True, "total": len(value), "result": value}
 
-    @asyncGen
     def web_bkk_input_prod(self):
         pars = {
             "EventTypeId": self.get_argument("eventType", ""),
@@ -539,10 +520,9 @@ class ProductionRequestManagerHandler(WebHandler):
             "ConditionDescription": self.get_argument("simDesc", ""),
         }
         gLogger.info(str(pars))
-        result = yield self.threadTask(BookkeepingClient().getProductions, pars)
+        result = BookkeepingClient().getProductions(pars)
         if not result["OK"]:
-            self.finish({"success": "false", "result": [], "total": 0, "error": result["Message"]})
-            return
+            return {"success": "false", "result": [], "total": 0, "error": result["Message"]}
         value = []
         if result["Value"]["Records"]:
             value.append({"id": 0, "text": "ALL"})
@@ -552,33 +532,30 @@ class ProductionRequestManagerHandler(WebHandler):
                 prod = -prod
             value.append({"id": prod, "text": prod})
         value.sort(key=lambda x: x["id"])
-        self.finish({"OK": True, "total": len(value), "result": value})
+        return {"OK": True, "total": len(value), "result": value}
 
-    @asyncGen
     def web_bkk_simcond(self):
-        result = yield self.threadTask(BookkeepingClient().getSimConditions)
+        result = BookkeepingClient().getSimConditions()
         if not result["OK"]:
-            self.finish({"success": "false", "result": [], "total": 0, "error": result["Message"]})
-            return
+            return {"success": "false", "result": [], "total": 0, "error": result["Message"]}
         rows = [dict(zip(self.bkSimCondFields, sc)) for sc in result["Value"]]
         # !!! Sorting and selection must be moved to MySQL/Service side
         result = SelectAndSort(self.request, rows, "simCondID")
-        self.finish(result)
+        return result
 
-    @asyncGen
     def web_getSimCondTree(self):
         _path, rtype, tree, dataQuality = self.__parseRequest()
         node = self.get_argument("node", "")
 
-        bk = LHCB_BKKDBClient(web=True)
+        bk = LHCB_BKKDBClient()
 
-        yield self.threadTask(bk.setFileTypes, [])
+        bk.setFileTypes([])
 
         bk.setAdvancedQueries(rtype)
         bk.setParameter(tree)
         bk.setDataQualities(dataQuality)
 
-        retVal = yield self.threadTask(bk.list, node)
+        retVal = bk.list(node)
 
         nodes = []
         if retVal:
@@ -601,21 +578,20 @@ class ProductionRequestManagerHandler(WebHandler):
                 nodes += [node]
 
         result = tornado.escape.json_encode(nodes)
-        self.finish(result)
+        return result
 
-    @asyncGen
     def web_bkk_input_tree(self):
         keep = ["simCondID", "condType", "inProPass", "evType"]
         node = self.get_argument("node", "")
 
-        bkcli = LHCB_BKKDBClient(web=True)
+        bkcli = LHCB_BKKDBClient()
 
         value = []
         level = ""
         scd = {}
         known = {}
 
-        nodes = yield self.threadTask(bkcli.list, node)
+        nodes = bkcli.list(node)
         for item in nodes:
             ipath = item["fullpath"]
             p = ipath.split("/")[1:]
@@ -653,9 +629,8 @@ class ProductionRequestManagerHandler(WebHandler):
                 known[x["text"]] = x
                 value.append(x)
         result = tornado.escape.json_encode(value)
-        self.finish(result)
+        return result
 
-    @asyncGen
     def web_save(self):
         rdict = {k: self.get_arguments(k, strip=False) for k in self.request.arguments}
         self.__unescape(rdict)
@@ -669,11 +644,10 @@ class ProductionRequestManagerHandler(WebHandler):
             try:
                 reqId = int(rdict["ID"])
             except Exception:
-                self.finish({"success": "false", "result": [], "total": 0, "error": "Request ID is not a number"})
-                return
+                return {"success": "false", "result": [], "total": 0, "error": "Request ID is not a number"}
             del rdict["ID"]
             req = self.__fromlocal(rdict)
-            result = yield self.threadTask(ProductionRequestClient().updateProductionRequest, reqId, req)
+            result = ProductionRequestClient().updateProductionRequest(reqId, req)
         else:
             sData = self.getSessionData()
 
@@ -681,17 +655,15 @@ class ProductionRequestManagerHandler(WebHandler):
 
             rdict["RequestAuthor"] = user
             req = self.__fromlocal(rdict)
-            result = yield self.threadTask(ProductionRequestClient().createProductionRequest, req)
+            result = ProductionRequestClient().createProductionRequest(req)
 
         if result["OK"]:
-            self.finish({"success": "true", "requestId": reqId})
+            return {"success": "true", "requestId": reqId}
         else:
             raise WErr.fromSERROR(result)
-        # self.finish()
 
-    @asyncGen
     def web_templates(self):
-        ret = yield self.threadTask(ProductionRequestClient().getProductionTemplateList)
+        ret = ProductionRequestClient().getProductionTemplateList()
         if not ret["OK"]:
             raise WErr.fromSERROR(ret)
 
@@ -704,7 +676,7 @@ class ProductionRequestManagerHandler(WebHandler):
             value.append(x)
         result = {"OK": True, "total": len(value), "result": value}
 
-        self.finish(result)
+        return result
 
     def getRequestFields(self):
         result = dict.fromkeys(self.localFields, None)
@@ -719,10 +691,9 @@ class ProductionRequestManagerHandler(WebHandler):
         result["userDN"] = sData["user"]["DN"]
         return result
 
-    @asyncGen
     def web_template_parlist(self):
         tpl_name = self.get_argument("tpl", "")
-        result = yield self.threadTask(ProductionRequestClient().getProductionTemplate, tpl_name)
+        result = ProductionRequestClient().getProductionTemplate(tpl_name)
         if not result["OK"]:
             raise WErr.fromSERROR(result)
         text = result["Value"]
@@ -734,7 +705,7 @@ class ProductionRequestManagerHandler(WebHandler):
         for x in tpf:
             if x not in rqf:
                 plist.append({"par": x, "label": tpf[x], "value": tpd[x].split("^")[0], "default": tpd[x]})
-        self.finish({"OK": True, "total": len(plist), "result": plist})
+        return {"OK": True, "total": len(plist), "result": plist}
 
     def getProductionRequest(self, ids):
         result = ProductionRequestClient().getProductionRequest(ids)
@@ -806,7 +777,6 @@ class ProductionRequestManagerHandler(WebHandler):
 
         return {"OK": True, "result": rows, "total": result["Value"]["Total"]}
 
-    @asyncGen
     def web_create_workflow(self):
         """!!! Note: 1 level parent=master assumed !!!"""
         rdict = {k: self.get_argument(k) for k in self.request.arguments}
@@ -838,7 +808,7 @@ class ProductionRequestManagerHandler(WebHandler):
             res = []
             for reqId in requests:
                 reqId = int(reqId)
-                retVal = yield self.threadTask(self.__createScript, rdict, reqId, operation, tpl_name, sdict)
+                retVal = self.__createScript(rdict, reqId, operation, tpl_name, sdict)
                 if retVal["OK"]:
                     res += [val for val in retVal["Value"]]
                 else:
@@ -847,12 +817,12 @@ class ProductionRequestManagerHandler(WebHandler):
                     )
                 if operation == "ScriptPreview":
                     break
-            self.finish(S_OK(res))
+            return S_OK(res)
         else:
-            retVal = yield self.threadTask(self.__createScript, rdict, reqId, operation, tpl_name, sdict)
+            retVal = self.__createScript(rdict, reqId, operation, tpl_name, sdict)
             if not retVal["OK"]:
                 raise WErr(404, "The following error occurred during the production creation: %s" % retVal["Message"])
-            self.finish(retVal)
+            return retVal
 
     def __createScript(self, rdict, reqId, operation, tpl_name, sdict):
         """
@@ -922,7 +892,7 @@ class ProductionRequestManagerHandler(WebHandler):
             # wf.setType( 'production/requests' )
             # try:
             #   wfxml = wf.toXML()
-            #   result = yield self.threadTask( ProductionRequestClient().publishWorkflow, str( wfxml ), True )
+            #   result = ProductionRequestClient().publishWorkflow(str( wfxml ), True )
             # except Exception, msg:
             #   result = {'OK':False, 'Message': str( msg )}
             # if not result['OK']:
@@ -936,7 +906,6 @@ class ProductionRequestManagerHandler(WebHandler):
             # return S_OK("Success with %s" % ','.join(success))
             return S_OK(success)
 
-    @asyncGen
     def web_split(self):
         try:
             reqId = int(self.get_argument("ID"))
@@ -944,21 +913,19 @@ class ProductionRequestManagerHandler(WebHandler):
         except Exception as e:
             raise WErr(400, "Wrong parameters (%s)" % str(e))
 
-        result = yield self.threadTask(ProductionRequestClient().splitProductionRequest, reqId, slist)
-        self.finish(result)
+        result = ProductionRequestClient().splitProductionRequest(reqId, slist)
+        return result
 
-    @asyncGen
     def web_progress(self):
         try:
             reqId = int(self.get_argument("RequestID", "0"))
         except Exception:
             raise WErr(500, "Request ID is not a number")
-        result = yield self.threadTask(ProductionRequestClient().getProductionProgressList, reqId)
+        result = ProductionRequestClient().getProductionProgressList(reqId)
         if not result["OK"]:
             raise WErr.fromSERROR(result)
-        self.finish({"OK": True, "result": result["Value"]["Rows"], "total": result["Value"]["Total"]})
+        return {"OK": True, "result": result["Value"]["Rows"], "total": result["Value"]["Total"]}
 
-    @asyncGen
     def web_add_production(self):
         try:
             requestID = int(self.get_argument("RequestID"))
@@ -966,25 +933,21 @@ class ProductionRequestManagerHandler(WebHandler):
         except Exception:
             raise WErr(500, "Incorrect Request or production ID")
 
-        result = yield self.threadTask(self.__bkProductionProgress, productionID)
+        result = self.__bkProductionProgress(productionID)
         bkEvents = 0 if not result["OK"] else result["Value"]
-        result = yield self.threadTask(
-            ProductionRequestClient().addProductionToRequest,
+        result = ProductionRequestClient().addProductionToRequest(
             {"ProductionID": productionID, "RequestID": requestID, "Used": 1, "BkEvents": bkEvents},
         )
-        self.finish(result)
+        return result
 
-    @asyncGen
     def web_remove_production(self):
         try:
             productionID = int(self.get_argument("ProductionID"))
         except ValueError:
             raise WErr(400, "Production ID is not a number")
 
-        result = yield self.threadTask(ProductionRequestClient().removeProductionFromRequest, productionID)
-        self.finish(result)
+        return ProductionRequestClient().removeProductionFromRequest(productionID)
 
-    @asyncGen
     def web_use_production(self):
         try:
             productionID = int(self.get_argument("ProductionID"))
@@ -992,29 +955,25 @@ class ProductionRequestManagerHandler(WebHandler):
         except ValueError:
             raise WErr(400, "Incorrect Production ID use Used flag")
 
-        result = yield self.threadTask(ProductionRequestClient().useProductionForRequest, productionID, used)
-        self.finish(result)
+        result = ProductionRequestClient().useProductionForRequest(productionID, used)
+        return result
 
-    @asyncGen
     def web_productions(self):
         try:
             prId = int(self.get_argument("RequestID"))
         except ValueError:
             raise WErr(400, "Request ID is not a number")
 
-        result = yield self.threadTask(ProductionRequestClient().getProductionList, prId)
+        result = ProductionRequestClient().getProductionList(prId)
         if not result["OK"]:
             raise WErr.fromSERROR(result)
-        self.finish({"OK": True, "result": result["Value"], "total": len(result["Value"])})
+        return {"OK": True, "result": result["Value"], "total": len(result["Value"])}
 
-    @asyncGen
     def web_getRequest(self):
         stepId = self.get_argument("StepId")
         requests = ProductionRequestManagerHandler.__dataCache.get("allData")
         if not requests:
-            retVal = yield self.threadTask(
-                ProductionRequestClient().getProductionRequestList, 0, "", "", 0, 0, {"RequestType": "Simulation"}
-            )
+            retVal = ProductionRequestClient().getProductionRequestList(0, "", "", 0, 0, {"RequestType": "Simulation"})
             if not retVal["OK"]:
                 raise WErr.fromSERROR(retVal)
             requests = retVal["Value"].get("Rows", [])
@@ -1029,16 +988,13 @@ class ProductionRequestManagerHandler(WebHandler):
                 record["RequestWG"] = request["RequestWG"]
                 record["RequestAuthor"] = request["RequestAuthor"]
                 records.append(record)
-        self.finish(
-            {
-                "success": "true",
-                "result": records,
-                "total": len(records),
-                "date": Time.dateTime().strftime("%Y-%m-%d %H:%M [UTC]"),
-            }
-        )
+        return {
+            "success": "true",
+            "result": records,
+            "total": len(records),
+            "date": datetime.datetime.utcnow().strftime("%Y-%m-%d %H:%M [UTC]"),
+        }
 
-    @asyncGen
     def web_getFastSimulationOpts(self):
         """
 
@@ -1052,4 +1008,4 @@ class ProductionRequestManagerHandler(WebHandler):
             fastsimTypes = gConfig.getValue("%s/FastSimulationType" % csS, fastsimTypes)
 
         rows = [{"text": i, "name": i} for i in fastsimTypes]
-        self.finish({"OK": True, "result": rows, "total": len(rows)})
+        return {"OK": True, "result": rows, "total": len(rows)}
