@@ -804,13 +804,6 @@ Ext.define("LHCbDIRAC.BookkeepingBrowser.classes.BookkeepingBrowser", {
             tooltip: "Click to show the attributtes of the selected job.",
           },
         },
-        {
-          text: "Logging information",
-          handler: me.getLoggingInfo,
-          properties: {
-            tooltip: "Shows the attributes of the selected job.",
-          },
-        },
       ],
     };
 
@@ -1217,28 +1210,4 @@ Ext.define("LHCbDIRAC.BookkeepingBrowser.classes.BookkeepingBrowser", {
       window.close();
     });
   },
-  getLoggingInfo: function () {
-    var me = this;
-    var lfn = GLOBAL.APP.CF.getFieldValueFromSelectedRow(me.grid, "Name");
-    Ext.Ajax.request({
-      url: GLOBAL.BASE_URL + me.applicationName + "/logfile",
-      params: {
-        lfn: lfn,
-      },
-      scope: me,
-      success: function (response) {
-        var me = this;
-        var response = Ext.JSON.decode(response.responseText);
-
-        if (response["success"] == "true") {
-          window.open("http://lhcb-logs.cern.ch/storage" + response["result"], "Log file", "width=400,height=200");
-        } else {
-          GLOBAL.APP.CF.alert(response["error"], "error");
-        }
-      },
-      failure: function (response) {
-        GLOBAL.APP.CF.showAjaxErrorMessage(response);
-      },
-    });
-  },
 });
