@@ -10,13 +10,7 @@
 \*****************************************************************************/
 Ext.define("LHCbDIRAC.ProductionRequestManager.classes.TemplateDetail", {
   extend: "Ext.panel.Panel",
-  tplMarkup: [
-    "<b>Name:</b> {display_name}<br/>",
-    "<b>Short description:</b> {Description}<br/>",
-    "<b>Author:</b> {Author}<br/>",
-    "<b>Last modified:</b> {PublishingTime}<br/>",
-    "<b>Description:</b> {LongDescription}<br/>",
-  ],
+  tplMarkup: ["<b>Name:</b> {display_name}<br/>"],
 
   initComponent: function () {
     var me = this;
